Lightkurve
==========

**A friendly package for Kepler & TESS time series analysis in Python.**

|pypi-badge| |ci-badge| |appveyor-badge| |cov-badge| |doi-badge|

.. |pypi-badge| image:: https://img.shields.io/pypi/v/lightkurve.svg
                :target: https://pypi.python.org/pypi/lightkurve
.. |ci-badge| image:: https://travis-ci.org/KeplerGO/lightkurve.svg?branch=master
              :target: https://travis-ci.org/KeplerGO/lightkurve
.. |appveyor-badge| image:: https://ci.appveyor.com/api/projects/status/6jvv5d7a142gwm8a/branch/master?svg=true
                    :target: https://ci.appveyor.com/project/mirca/lightkurve
.. |cov-badge| image:: https://codecov.io/gh/KeplerGO/lightkurve/branch/master/graph/badge.svg
              :target: https://codecov.io/gh/KeplerGO/lightkurve
.. |doi-badge| image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1181928.svg
              :target: https://doi.org/10.5281/zenodo.1181928


**Lightkurve** is a community-developed, open-source Python package which offers a beautiful and user-friendly way
to analyze astronomical flux time series data,
in particular the pixels and lightcurves obtained by
**NASA's Kepler and TESS exoplanet missions**.

.. image:: https://raw.githubusercontent.com/KeplerGO/lightkurve/master/docs/source/_static/images/lightkurve-teaser.gif

This package aims to lower the barrier for students, astronomers,
and citizen scientists interested in analyzing Kepler and TESS space telescope data.
It does this by providing **high-quality building blocks and tutorials**
which enable both hand-tailored data analyses and advanced automated pipelines.


Documentation
-------------

Read the documentation at `http://docs.lightkurve.org <http://docs.lightkurve.org>`_.


Quickstart
----------
If you have a working version of Python 2 or 3 on your system, you can simply install this package using `pip`:
::

  pip install lightkurve

Once installed, visit our quickstart guide at `http://docs.lightkurve.org/quickstart.html <http://docs.lightkurve.org/quickstart.html>`_.


Contributing
------------

We welcome community contributions from everyone!
Please read the contribution guidelines at `http://docs.lightkurve.org/about/contributing.html <http://docs.lightkurve.org/about/contributing.html>`_.


Citing
------

If you find Lightkurve useful in your research, please cite it and give us a GitHub star!
Please read the citation instructions at `http://docs.lightkurve.org/about/citing.html <http://docs.lightkurve.org/about/citing.html>`_.


Contact
-------
Lightkurve is an open source community project created by `the authors <AUTHORS.rst>`_ and supported by the
`Kepler/K2 Guest Observer Office <https://keplerscience.arc.nasa.gov>`_.
You can contact us via keplergo@mail.arc.nasa.gov.
